==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/ru_RU.php <==
<?php
$lang['friendlyname'] = 'Менеджер файлов';
$lang['permission'] = 'Использование модуля File Manager ';
$lang['permissionadvanced'] = 'Расширенное использование модуля File Manager ';
$lang['moddescription'] = 'Обрабатывание файлов и каталогов на закачку в файловом разделе cmsms';
$lang['installed'] = 'FileManager версии %s установлен';
$lang['postinstall'] = 'Модуль FileManager установлен';
$lang['uninstalled'] = 'Модуль FileManager удалён';
$lang['really_uninstall'] = 'Вы уверены, что хотите удалить FileManager ?';
$lang['upgraded'] = 'Модуль FileManager был обновлён до версии %s';
$lang['fileview'] = 'Просмотр файла';
$lang['switchtofileview'] = 'Переключить на просмотр файла';
$lang['settings'] = 'Настройки';
$lang['savesettings'] = 'Сохранить настройки';
$lang['filename'] = 'Имя файла';
$lang['fileinfo'] = 'Инфо';
$lang['fileowner'] = 'Владелец';
$lang['fileperms'] = 'Права';
$lang['filesize'] = 'Размер';
$lang['filedate'] = 'Дата';
$lang['actions'] = 'Действия';
$lang['delete'] = 'Удалить';
$lang['notwritable'] = 'Не перезаписываемый';
$lang['filetoobig'] = 'является слишком большим. Загрузка отменена.';
$lang['unknown'] = 'Неизвестная величина';
$lang['fileoutsideuploads'] = 'Вы не можете изменять файлы вне каталога uploads! (Для этого требуются дополнительные права управления файлами)';
$lang['writable'] = 'Доступно для записи';
$lang['writeprotected'] = 'Недоступно для записи';
$lang['bytes'] = 'байтов';
$lang['kb'] = 'Кб';
$lang['mb'] = 'Мб';
$lang['files'] = 'файлах';
$lang['bytesin'] = 'байтов в ';
$lang['in'] = 'в';
$lang['file'] = 'файле';
$lang['fileno'] = 'Файл номер';
$lang['subdirs'] = 'подкаталогах';
$lang['subdir'] = 'подкаталоге';
$lang['and'] = 'и';
$lang['confirmsingledelete'] = 'Вы уверены?';
$lang['confirmsingledirdelete'] = 'Вы уверены, что хотите удалить этот кталог?';
$lang['dirtreedeletesuccess'] = 'Каталог, включая содержимое был успешно удалён.';
$lang['dirtreedeletefail'] = 'Произошла ошибка при удалении этой директории. Однако, что-то из содержимого, возможно, было удалено.';
$lang['singlefiledeletesuccess'] = 'Файл был успешно удалён';
$lang['filedeletesuccess'] = 'был успешно удалён';
$lang['singlefiledeletefail'] = 'Произошла ошибка во время попытки удалить файл';
$lang['filedeletefail'] = 'не был удалён из-за ошибки';
$lang['singledirdeletesuccess'] = 'Каталог был успешно удалён';
$lang['singledirdeletefail'] = 'Произошла ошибка во время попытки удалить кактлог (вероятно, он пустой?)';
$lang['deleteselected'] = 'Удалить выбранные файлы';
$lang['confirmselected'] = 'Вы уверены?';
$lang['confirmdeleteselected'] = 'Вы уверены, что выбранные файлы должны быть удалены?';
$lang['deleteselectedcancelled'] = 'Удаление выбранных файлов отменено';
$lang['recursetext'] = 'Рекурсивно подкаталоги (не сделано)';
$lang['nofilesselected'] = 'Нет выбранных файлов';
$lang['moveselected'] = 'Переместить выбранные файлы';
$lang['copyselected'] = 'Копировать выбранные файлы';
$lang['selecttargetdir'] = 'Выбор папки назначения для перемещения/копирования';
$lang['movedto'] = 'перемещён в';
$lang['copiedto'] = 'скопирован в';
$lang['couldnotmove'] = 'не могут быть перенесены';
$lang['couldnotcopy'] = 'не могут быть скопированы';
$lang['rename'] = 'Переименовать';
$lang['newname'] = 'Новое имя:';
$lang['renamesuccess'] = 'Файл успешно переименован';
$lang['renamefailure'] = 'Переименование файла не удалось';
$lang['renamecancelled'] = 'Переменование отменено';
$lang['owner'] = 'Пользователь';
$lang['group'] = 'Группа';
$lang['others'] = 'Другие';
$lang['newpermissions'] = 'Новые разрешения:';
$lang['setpermissions'] = 'Установить разрешения';
$lang['permissionstyle'] = 'Стиль разрешений';
$lang['rwxstyle'] = 'rwx стиль';
$lang['755style'] = '755 стиль';
$lang['quickmode'] = 'Быстрая смена прав (chmod 777)';
$lang['chmod'] = 'Изменить разрешения';
$lang['chmodselected'] = 'Изменения разрешений на отдельные файлы';
$lang['chmodsuccess'] = 'Файл успешно получил новые права';
$lang['chmodfailure'] = 'Изменение прав файла не удалось';
$lang['chmodcancelled'] = 'Изменение разрешений аннулированы';
$lang['dirchmodfailmulti'] = 'Невозможно изменение прав на каталог, но возможно, что новые права были присвоены отдельным файлам в каталоге.';
$lang['dirchmodsuccessmulti'] = 'Изменение прав для каталога и его содержимого было успешно произведено';
$lang['dirchmodsuccess'] = 'Изменение разрешений каталога выполнено';
$lang['dirchmodfailure'] = 'Изменение разрешений каталога не выполнено';
$lang['dirnotemptyconfirm'] = 'Этот каталог не является пустым. Вы действительно хотите удалить его вместе со всем содержимым, включая подкаталоги?';
$lang['dirtreedeletecancelled'] = 'Удаление каталога отменено';
$lang['imsure'] = 'Я уверен';
$lang['cancel'] = 'Отмена';
$lang['ok'] = 'ОК';
$lang['uploadnewfile'] = 'Загрузить новый файл(ы):';
$lang['unpackafterupload'] = 'Попробовать распаковать файл после загрузки (только tgz и большинство zip-файлов)?';
$lang['uploadsuccess'] = 'был успешно загружен';
$lang['uploadfail'] = 'не удалось загрузить успешно';
$lang['unpacksuccess'] = 'был успешно распакован';
$lang['unpackfail'] = 'не удалось с этой ошибкой:';
$lang['packfileopenfail'] = 'Невозможно открыть упакованный файл для распаковки (вероятно, неподдерживаемый формат?)';
$lang['packfilewritefail'] = 'Не удалось открыть файл &s для записи';
$lang['currentpath'] = 'Текущий путь:';
$lang['newdirname'] = 'Создать новый каталог:';
$lang['newdirsuccess'] = 'Каталог был успешно создан';
$lang['newdirfail'] = 'Произошла ошибка во время попытки создания каталога';
$lang['invalidnewdir'] = 'Имя нового каталога не может содержать символы /, \\ и \'..\'';
$lang['filedateformat'] = 'm/d/Y Н:m:s';
$lang['iconsize'] = 'Размер значка';
$lang['smallicons'] = 'Маленький значок';
$lang['largeicons'] = 'Крупный значок';
$lang['thousanddelimiter'] = 'Разделитель тысяч';
$lang['none'] = 'нет';
$lang['space'] = 'пробел';
$lang['showthumbnails'] = 'Показывать миниатюры';
$lang['showthumbnailshelp'] = 'Включение этой функции приведет к показу эскизов изображений, если они существуют, и скроет показ самих графических файлов. Отключение функции приведет к показу всех файлов.';
$lang['uploadfilesto'] = 'Загрузить файлы в:';
$lang['uploadview'] = 'Загрузить файлы';
$lang['uploadboxes'] = 'Количество потоков';
$lang['nothinguploaded'] = 'Ничего не загружено';
$lang['unsupportedarchive'] = 'Неподдерживаемый формат архива';
$lang['uploadmethod'] = 'Метод загрузки';
$lang['uploaderstandard'] = 'Стандартный метод html ввода (возможность распаковки)';
$lang['enableadvanced'] = 'Включить расширенный режим?';
$lang['advancedhelp'] = 'Позволяет получить доступ к файловой системе cmsms в целом, а не только в /uploads/ (если это разрешено)';
$lang['showhiddenfileshelp'] = 'Эффективно только в расширенном режиме';
$lang['showhiddenfiles'] = 'Показывать скрытые файлы';
$lang['settingsconfirmsingledelete'] = 'Подтвердить удаление единственного файла?';
$lang['settingssaved'] = 'Настройки сохранены';
$lang['help'] = '                <h3>Что делает этот модуль?</h3>
		<p>Этот модуль добавляет менеджер файлов</p>
		<h3>Как мне им пользоваться?</h3>
		<p>Он находиться в меню "Контент" административного интерфейса</p>';
$lang['utma'] = '156861353.1044124068342992300.1242846023.1243210765.1243212722.10';
$lang['utmz'] = '156861353.1243203801.7.6.utmcsr=cmsmadesimple.ru|utmccn=(referral)|utmcmd=referral|utmcct=/features/razrabotka';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p3.tgz: cms/modules/FileManager/lang/ext/ru_RU.php <==
<?php
$lang['friendlyname'] = 'Менеджер файлов';
$lang['permission'] = 'Использование модуля File Manager ';
$lang['permissionadvanced'] = 'Расширенное использование модуля File Manager ';
$lang['moddescription'] = 'Обрабатывание файлов и каталогов на закачку в файловом разделе cmsms';
$lang['installed'] = 'FileManager версии %s установлен';
$lang['postinstall'] = 'Модуль FileManager установлен';
$lang['uninstalled'] = 'Модуль FileManager удалён';
$lang['really_uninstall'] = 'Вы уверены, что хотите удалить FileManager ?';
$lang['upgraded'] = 'Модуль FileManager был обновлён до версии %s';
$lang['fileview'] = 'Просмотр файла';
$lang['switchtofileview'] = 'Переключить на просмотр файла';
$lang['settings'] = 'Настройки';
$lang['savesettings'] = 'Сохранить настройки';
$lang['postletexists'] = 'Внимание! Пожалуйста, полностью удалите папку modules/FileManager/postlet, так как она не используется уже очень давно.';
$lang['filename'] = 'Имя файла';
$lang['fileinfo'] = 'Инфо';
$lang['fileowner'] = 'Владелец';
$lang['fileperms'] = 'Права';
$lang['filesize'] = 'Размер';
$lang['filedate'] = 'Дата';
$lang['actions'] = 'Действия';
$lang['delete'] = 'Удалить';
$lang['notwritable'] = 'Не перезаписываемый';
$lang['afileistoobig'] = 'Слишком большой размер файла. Загрузка прервана.';
$lang['unknown'] = 'Неизвестная величина';
$lang['fileoutsideuploads'] = 'Вы не можете изменять файлы вне каталога uploads! (Для этого требуются дополнительные права управления файлами)';
$lang['writable'] = 'Доступно для записи';
$lang['writeprotected'] = 'Недоступно для записи';
$lang['bytes'] = 'байтов';
$lang['kb'] = 'Кб';
$lang['mb'] = 'Мб';
$lang['files'] = 'файлах';
$lang['bytesin'] = 'байтов в ';
$lang['in'] = 'в';
$lang['file'] = 'файле';
$lang['fileno'] = 'Файл номер';
$lang['subdirs'] = 'подкаталогах';
$lang['subdir'] = 'подкаталоге';
$lang['and'] = 'и';
$lang['confirmsingledelete'] = 'Вы уверены?';
$lang['confirmsingledirdelete'] = 'Вы уверены, что хотите удалить этот кталог?';
$lang['dirtreedeletesuccess'] = 'Каталог, включая содержимое был успешно удалён.';
$lang['dirtreedeletefail'] = 'Произошла ошибка при удалении этой директории. Однако, что-то из содержимого, возможно, было удалено.';
$lang['singlefiledeletesuccess'] = 'Файл был успешно удалён';
$lang['filedeletesuccess'] = 'был успешно удалён';
$lang['singlefiledeletefail'] = 'Произошла ошибка во время попытки удалить файл';
$lang['filedeletefail'] = 'не был удалён из-за ошибки';
$lang['singledirdeletesuccess'] = 'Каталог был успешно удалён';
$lang['singledirdeletefail'] = 'Произошла ошибка во время попытки удалить кактлог (вероятно, он пустой?)';
$lang['deleteselected'] = 'Удалить выбранные файлы';
$lang['confirmselected'] = 'Вы уверены?';
$lang['confirmdeleteselected'] = 'Вы уверены, что выбранные файлы должны быть удалены?';
$lang['deleteselectedcancelled'] = 'Удаление выбранных файлов отменено';
$lang['recursetext'] = 'Рекурсивно подкаталоги (не сделано)';
$lang['nofilesselected'] = 'Нет выбранных файлов';
$lang['moveselected'] = 'Переместить выбранные файлы';
$lang['copyselected'] = 'Копировать выбранные файлы';
$lang['selecttargetdir'] = 'Выбор папки назначения для перемещения/копирования';
$lang['movedto'] = 'перемещён в';
$lang['copiedto'] = 'скопирован в';
$lang['couldnotmove'] = 'не могут быть перенесены';
$lang['couldnotcopy'] = 'не могут быть скопированы';
$lang['filesdeletedsuccessfully'] = '%s файл(а) был(и) успешно удалены';
$lang['filesdeletedfiled'] = '%s файл(а) не могут быть удалены';
$lang['filesmovedsuccessfully'] = '%s файл(а) был(и) были успешно перенесены';
$lang['filesmovedfailed'] = '%s файл(а) не могут быть перенесены';
$lang['filescopiedsuccessfully'] = '%s файл(а) был(и) успешно скопированы';
$lang['filescopiedfailed'] = '%s файл(а) не могут быть скопированы';
$lang['internalerror'] = 'Внутренняя ошибка (означает, что произошло что-то бессмысленное, опишите подробно, что Вы делали, когда возникла эта ошибка)';
$lang['rename'] = 'Переименовать';
$lang['newname'] = 'Новое имя:';
$lang['renamesuccess'] = 'Файл успешно переименован';
$lang['renamefailure'] = 'Переименование файла не удалось';
$lang['renamecancelled'] = 'Переменование отменено';
$lang['owner'] = 'Пользователь';
$lang['group'] = 'Группа';
$lang['others'] = 'Другие';
$lang['newpermissions'] = 'Новые разрешения:';
$lang['setpermissions'] = 'Установить разрешения';
$lang['permissionstyle'] = 'Стиль разрешений';
$lang['rwxstyle'] = 'rwx стиль';
$lang['755style'] = '755 стиль';
$lang['quickmode'] = 'Быстрая смена прав (chmod 777)';
$lang['chmod'] = 'Изменить разрешения';
$lang['chmodselected'] = 'Изменения разрешений на отдельные файлы';
$lang['chmodsuccess'] = 'Файл успешно получил новые права';
$lang['chmodfailure'] = 'Изменение прав файла не удалось';
$lang['chmodcancelled'] = 'Изменение разрешений аннулированы';
$lang['newuploadfailed'] = '%s файл(а) не был(и) загружены (или разархивированы)';
$lang['newuploadsuccess'] = '%s файл(а) были загружены (и разархивированы при необходимости)';
$lang['dirchmodfailmulti'] = 'Невозможно изменение прав на каталог, но возможно, что новые права были присвоены отдельным файлам в каталоге.';
$lang['dirchmodsuccessmulti'] = 'Изменение прав для каталога и его содержимого было успешно произведено';
$lang['dirchmodsuccess'] = 'Изменение разрешений каталога выполнено';
$lang['dirchmodfailure'] = 'Изменение разрешений каталога не выполнено';
$lang['dirnotemptyconfirm'] = 'Этот каталог не является пустым. Вы действительно хотите удалить его вместе со всем содержимым, включая подкаталоги?';
$lang['dirtreedeletecancelled'] = 'Удаление каталога отменено';
$lang['imsure'] = 'Я уверен';
$lang['cancel'] = 'Отмена';
$lang['ok'] = 'ОК';
$lang['uploadnewfile'] = 'Загрузить новый файл(ы):';
$lang['unpackafterupload'] = 'Попробовать распаковать файл после загрузки (только tgz и большинство zip-файлов)?';
$lang['uploadsuccess'] = 'был успешно загружен';
$lang['uploadfail'] = 'не удалось загрузить успешно';
$lang['unpacksuccess'] = 'был успешно распакован';
$lang['unpackfail'] = 'не удалось с этой ошибкой:';
$lang['packfileopenfail'] = 'Невозможно открыть упакованный файл для распаковки (вероятно, неподдерживаемый формат?)';
$lang['packfilewritefail'] = 'Не удалось открыть файл &s для записи';
$lang['afilecontainsillegalchars'] = 'Имя файла содержит один или несколько недопустимых знаков (\',",+,*,\\,/,&,$). Загрузка остановлена.';
$lang['currentpath'] = 'Текущий путь:';
$lang['newdirname'] = 'Создать новый каталог:';
$lang['newdirsuccess'] = 'Каталог был успешно создан';
$lang['newdirfail'] = 'Произошла ошибка во время попытки создания каталога';
$lang['direxists'] = 'Каталог с этим названием уже существует';
$lang['invalidnewdir'] = 'Имя нового каталога не может содержать символы /, \\ и \'..\'';
$lang['filedateformat'] = 'm/d/Y Н:m:s';
$lang['iconsize'] = 'Размер значка';
$lang['smallicons'] = 'Маленький значок';
$lang['largeicons'] = 'Крупный значок';
$lang['thousanddelimiter'] = 'Разделитель тысяч';
$lang['none'] = 'нет';
$lang['space'] = 'пробел';
$lang['showthumbnails'] = 'Показывать миниатюры';
$lang['showthumbnailshelp'] = 'Включение этой функции приведет к показу эскизов изображений, если они существуют, и скроет показ самих графических файлов. Отключение функции приведет к показу всех файлов.';
$lang['uploadfilesto'] = 'Загрузить файлы в:';
$lang['uploadview'] = 'Загрузить файлы';
$lang['uploadboxes'] = 'Количество потоков';
$lang['nothinguploaded'] = 'Ничего не загружено';
$lang['newunsupportedarchive'] = '%s в неподдерживаемом формате';
$lang['uploadmethod'] = 'Метод загрузки';
$lang['uploaderstandard'] = 'Стандартный метод html ввода (возможность распаковки)';
$lang['enableadvanced'] = 'Включить расширенный режим?';
$lang['advancedhelp'] = 'Позволяет получить доступ к файловой системе cmsms в целом, а не только в /uploads/ (если это разрешено)';
$lang['showhiddenfileshelp'] = 'Эффективно только в расширенном режиме';
$lang['showhiddenfiles'] = 'Показывать скрытые файлы';
$lang['settingsconfirmsingledelete'] = 'Подтвердить удаление единственного файла?';
$lang['settingssaved'] = 'Настройки сохранены';
$lang['help'] = '                <h3>Что делает этот модуль?</h3>
		<p>Этот модуль добавляет менеджер файлов</p>
		<h3>Как мне им пользоваться?</h3>
		<p>Он находиться в меню "Контент" административного интерфейса</p>';
$lang['qca'] = 'P0-1938388883-1277855813144';
$lang['utma'] = '156861353.429593658.1277855813.1295220134.1295225172.173';
$lang['utmz'] = '156861353.1295194781.170.80.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
